@@ -1,6 +1,13 @@
 import os
+import time
 import logging
 
+from fintix_modelcurator.const import *
+
+
+def get_currenttime_ms():
+    return time.time() // 1_000_000
+
 
 def handle_error(error, logger=None):
     if logger is None:
@@ -23,3 +30,7 @@ def handle_error(error, logger=None):
 
 def handle_error(error):
     handle_error(error, None)
+
+
+def get_model_save_path(model_name):
+    return os.path.join(LOCAL_DEPLOY_MODEL_REPO, model_name)
